@@ -362,7 +362,7 @@ class PixelMapFit:
                 gaia_data = self.gaiadata
                 no_gaia_data_message = ValueError('No gaia data initialized in PixelMapPeriodogram class')
                 if gaia_data ==None :
-                    raise no_gaia_data_message
+                    starlist = None
 
                 else:
                     distances = np.square(self.x-gaia_data['x'])+np.square(self.y-gaia_data['y'])
@@ -380,11 +380,13 @@ class PixelMapFit:
                     
         fh = frequency_heatmap(self.tpf,self.heatmap,self.heatmap_error,self.frequency_list,self.gaiadata) 
         fh.location()
-        fh.star_list()
         self.location = [fh.x,fh.y]
         self.heatmap = self.heatmap.sum(axis=0).reshape(self.aperture.shape[0],self.aperture.shape[1]) / np.sqrt((self.heatmap_error**2).sum(axis=0)).reshape(self.aperture.shape[0],self.aperture.shape[1])
-        self.starfit= fh.stars.reset_index()
         self.result = fh.result
+        if (self.gaiadata !=None):
+            fh.star_list()
+            self.starfit= fh.stars.reset_index()
+
     
     def info(self):
         plt.imshow(self.heatmap,origin='lower')
@@ -392,10 +394,9 @@ class PixelMapFit:
         if (self.gaiadata != None):
             plt.scatter(self.gaiadata['x'],self.gaiadata['y'],s=self.gaiadata['size']*5,c='white',alpha=.6)
             plt.scatter(self.location[0],self.location[1],marker='X',c='black',s=70)
-            
+            print(self.starfit)
         plt.xlim(-.5,self.aperture.shape[1]-1+.5)
         plt.ylim(-.5,self.aperture.shape[0]-1+.5)
-        print(self.starfit)
         report_fit(self.result)
         if (np.asarray([self.result.params['height{0:d}'.format(j)].stderr for j in np.arange(len(self.frequency_list))]) / np.asarray([self.result.params['height{0:d}'.format(j)].value for j in np.arange(len(self.frequency_list))])).any() >.2:
             Warning('Frequencies used may not all belong to the same source and provided fit could be unreliable')
